@@ -7,8 +7,6 @@ import os
 from keras.preprocessing import text as tx
 from pkg_resources import resource_filename
 
-from . import resources
-
 
 class FeatureExtractor(object):
     def __init__(self, flatten):
@@ -397,8 +395,8 @@ class FeatureExtractor(object):
             features, feature_labels = features_dict[feature](text)
             if self.flatten and isinstance(features, list):
                 for f, l in zip(features, feature_labels):
-                    output_dict[f] = l
+                    output_dict[l] = f
             else:
-                output_dict[feature] = features
+                output_dict[feature] = features 
 
         return output_dict
